@@ -12,7 +12,7 @@ sub new {
 }
 
 sub lock {
-    shift->{locked} = $$;
+    $_[0]->{locked} = $$;
 }
 
 sub locked {
@@ -21,15 +21,29 @@ sub locked {
 }
 
 sub unlock {
-    delete shift->{locked};
+    delete $_[0]->{locked};
 }
 
 sub time {
-    shift->{time} || 0;
+    $_[0]->{time} || 0;
 }
 
 sub touch {
-    shift->{time} = Time::HiRes::time;
+    $_[0]->{time} = Time::HiRes::time;
+    $_[0]->not_queued;
+}
+
+sub be_queued {
+    $_[0]->{queued} = 1;
+}
+
+sub queued {
+    exists $_[0]->{queued}
+      and $_[0]->{queued};
+}
+
+sub not_queued {
+    delete $_[0]->{queued};
 }
 
 1;
